Package: bpca
Version: 1.5-0
Date: 2026-05-25
Title: Biplot Analysis for Multivariate Data Using Principal Components
Authors@R: c(person("José C.", "Faria", role = c("aut", "cre"),
               email = "joseclaudio.faria@gmail.com"),
             person("Ivan B.", "Allaman", role = "aut"),
             person("Clarice G. B.", "Demétrio", role = "aut"))
Maintainer: José C. Faria <joseclaudio.faria@gmail.com>
Depends: R (>= 4.1.0)
Imports: scatterplot3d, rgl, xtable
Suggests: knitr, rmarkdown, testthat (>= 3.0.0)
Config/testthat/edition: 3
VignetteBuilder: knitr
Description: Provides tools for creating 2D and 3D biplots of multivariate data
    based on principal components analysis, together with diagnostics for
    reduction quality and enhanced visualization of variables and objects.
License: GPL-2
URL: https://github.com/jcfaria/bpca
BugReports: https://github.com/jcfaria/bpca/issues
Encoding: UTF-8
LazyData: true
NeedsCompilation: no
Packaged: 2026-05-25 16:33:37 UTC; jcfaria
Author: José C. Faria [aut, cre],
  Ivan B. Allaman [aut],
  Clarice G. B. Demétrio [aut]
Repository: CRAN
Date/Publication: 2026-05-25 17:30:02 UTC
Built: R 4.6.0; ; 2026-05-25 18:25:04 UTC; unix
